NAME

DBIO::MySQL::EV::ConnectInfo - MySQL/MariaDB connection-info utilities for DBIO async driver

VERSION

version 0.900001

my $async_info = dbi_to_conninfo([ 'dbi:MariaDB:database=test;host=localhost', $user, $pass, \%attrs ]);

Translate a DBI-style connect-info arrayref ([$dsn, $user, $pass, \%attrs], as produced by the sync DBIO::MySQL::Storage) into the async [ \%conninfo, \%opts ] shape consumed by DBIO::MySQL::EV::Storage.

The dbi:mysql: / dbi:MariaDB: DSN is parsed into named EV::MariaDB parameters (host, port, database, ...); dbname is normalised to database (EV::MariaDB's spelling). $user / $pass fill in user / password when not already present in the DSN. A pool_size attribute, if given, is carried into the conninfo hash. Dies unless the DSN is in a dbi:mysql:-family form, since EV::MariaDB does not understand the DSN string.

AUTHOR

DBIO Authors

COPYRIGHT AND LICENSE

Copyright (C) 2026 DBIO Authors

This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.

1 POD Error

The following errors were encountered while parsing the POD:

Around line 48:

Unknown directive: =func